import React, { memo } from 'react';
import ReactMarkdown from 'react-markdown';
import { openLink } from '../misc/other';
import Logo from '../../public/icons/Logo-ProxyScrape-colored.png';
import CloseIcon from './ui/CloseIcon';

import '../../public/styles/Info.postcss';

const Info = memo(({ show, releases, toggleInfo }) => {
    if (releases === undefined) return null;

    return (
        <div className={`info-wrap ${show && 'active'}`}>
            <div className='info-content'>
                <CloseIcon onChange={toggleInfo}/>
                <div className='section'>
                    <a href='https://proxyscrape.com/home?ref=proxy-checker' title='Contact Us' onClick={openLink}>
                        <img src={Logo} width="175" height="22.2"/>
                    </a>
                </div>
                <div className='description'>
                    <div className="part">
                        <div> Need help? Contact us via our 24/7 live chat or via </div>
                        <a href='https://proxyscrape.com/contact?ref=proxy-checker' title='Contact Us' onClick={openLink}>
                            <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" className="bi bi-envelope" viewBox="0 0 16 16"> <path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4Zm2-1a1 1 0 0 0-1 1v.217l7 4.2 7-4.2V4a1 1 0 0 0-1-1H2Zm13 2.383-4.708 2.825L15 11.105V5.383Zm-.034 6.876-5.64-3.471L8 9.583l-1.326-.795-5.64 3.47A1 1 0 0 0 2 13h12a1 1 0 0 0 .966-.741ZM1 11.105l4.708-2.897L1 5.383v5.722Z"/> </svg>
                            <span>email</span>
                        </a>
                    </div>
                    <div className="part">We are happy to help you with all your proxy needs!</div>
                    <div className="part">
                        <div>If you are looking for datacenter proxies with 99% uptime, take a look at </div>
                        <a href='https://proxyscrape.com/premium?ref=proxy-checker' title='Premium' onClick={openLink}>
                            <svg data-v-3a6b5165='' viewBox='0 0 512 512'>
                                <path
                                    data-v-3a6b5165=''
                                    d='m464.626 107.556-21.551 21.551c25.306 37.14 38.925 80.967 38.925 126.893 0 60.367-23.508 117.12-66.194 159.806s-99.439 66.194-159.806 66.194c-45.926 0-89.753-13.62-126.893-38.925l-21.551 21.551c43.051 30.77 94.469 47.374 148.444 47.374 68.38 0 132.667-26.629 181.02-74.98 48.351-48.352 74.98-112.64 74.98-181.02 0-53.975-16.604-105.393-47.374-148.444z'
                                ></path>
                                <path
                                    data-v-3a6b5165=''
                                    d='m68.925 382.893c-25.306-37.14-38.925-80.967-38.925-126.893 0-60.367 23.508-117.12 66.194-159.806s99.439-66.194 159.806-66.194c45.926 0 89.753 13.62 126.893 38.925l21.551-21.551c-43.051-30.77-94.469-47.374-148.444-47.374-68.38 0-132.667 26.629-181.02 74.98-48.351 48.352-74.98 112.64-74.98 181.02 0 53.975 16.604 105.393 47.374 148.444z'
                                ></path>
                                <path
                                    data-v-3a6b5165=''
                                    d='m256 425.89 182.144-170.679-64.127-131.544h-236.034l-64.127 131.544zm-38.189-189.056h-101.621l35.049-71.898zm53.189 30h110.864l-110.864 103.887zm22.696-30 66.47-73.117 35.644 73.117zm-37.798-3.021-74.209-80.146h147.069zm-14.898 33.021v103.887l-110.864-103.887z'
                                ></path>
                            </svg>
                            <span>ProxyScrape Premium</span>
                        </a>
                    </div>
                </div>
                <div className='section'>
                    <svg viewBox='0 0 512 512'>
                        <path d='M510.394,203.263L422.222,91.044c-1.424-1.813-3.602-2.872-5.909-2.872H353.19c-4.151,0-7.515,3.364-7.515,7.515    s3.364,7.515,7.515,7.515h59.47l82.268,104.705L412.66,312.61H296.077c-2.513,0-4.859,1.255-6.252,3.347l-57.872,86.81    l-57.872-86.81c-1.394-2.091-3.739-3.347-6.252-3.347H15.029V103.201h301.088c4.151,0,7.515-3.364,7.515-7.515    s-3.364-7.515-7.515-7.515H7.515C3.365,88.172,0,91.536,0,95.687v224.438c0,4.151,3.365,7.515,7.515,7.515h156.291l61.894,92.841    c2.922,4.385,9.583,4.386,12.504,0l61.895-92.841h116.214c2.307,0,4.485-1.059,5.909-2.872l88.172-112.219    C512.535,209.824,512.535,205.988,510.394,203.263z' />
                        <path d='M151.796,344.673H71.64c-4.15,0-7.515,3.364-7.515,7.515s3.365,7.515,7.515,7.515h80.157c4.15,0,7.515-3.364,7.515-7.515    S155.947,344.673,151.796,344.673z' />
                        <path d='M167.828,376.736H87.671c-4.15,0-7.515,3.364-7.515,7.515s3.365,7.515,7.515,7.515h80.157c4.15,0,7.515-3.364,7.515-7.515    S171.978,376.736,167.828,376.736z' />
                        <path d='M191.875,408.798h-88.172c-4.15,0-7.515,3.364-7.515,7.515s3.365,7.515,7.515,7.515h88.172    c4.15,0,7.515-3.364,7.515-7.515S196.025,408.798,191.875,408.798z' />
                        <path d='M79.656,168.329H47.593c-4.15,0-7.515,3.364-7.515,7.515v64.125c0,4.151,3.365,7.515,7.515,7.515s7.515-3.364,7.515-7.515    v-24.548H71.64c4.15,0,7.515-3.364,7.515-7.515s-3.365-7.515-7.515-7.515H55.108v-17.033h24.548c4.15,0,7.515-3.364,7.515-7.515    S83.806,168.329,79.656,168.329z' />
                        <path d='M127.75,168.329c-17.403,0-31.562,17.755-31.562,39.577s14.159,39.577,31.562,39.577s31.562-17.755,31.562-39.577    S145.153,168.329,127.75,168.329z M127.75,232.454c-8.961,0-16.532-11.242-16.532-24.548s7.571-24.548,16.532-24.548    s16.532,11.242,16.532,24.548S136.711,232.454,127.75,232.454z' />
                        <path d='M320.125,168.329c-17.403,0-31.562,17.755-31.562,39.577s14.159,39.577,31.562,39.577s31.562-17.755,31.562-39.577    S337.528,168.329,320.125,168.329z M320.125,232.454c-8.961,0-16.532-11.242-16.532-24.548s7.571-24.548,16.532-24.548    s16.532,11.242,16.532,24.548S329.087,232.454,320.125,232.454z' />
                        <path d='M215.922,232.454h-24.548v-56.611c0-4.151-3.365-7.515-7.515-7.515c-4.15,0-7.515,3.364-7.515,7.515v64.125    c0,4.151,3.365,7.515,7.515,7.515h32.063c4.15,0,7.515-3.364,7.515-7.515S220.072,232.454,215.922,232.454z' />
                        <path d='M272.031,232.454h-24.548v-56.611c0-4.151-3.365-7.515-7.515-7.515s-7.515,3.364-7.515,7.515v64.125    c0,4.151,3.365,7.515,7.515,7.515h32.063c4.151,0,7.515-3.364,7.515-7.515S276.182,232.454,272.031,232.454z' />
                        <path d='M433.277,168.386c-4.122-0.505-7.874,2.406-8.389,6.525l-5.315,42.524l-12.846-21.411    c-1.469-2.448-4.203-3.859-7.044-3.624c-2.847,0.228-5.317,2.049-6.377,4.699l-7.4,18.5L375.51,174.02    c-1.008-4.026-5.089-6.469-9.114-5.468c-4.027,1.007-6.474,5.087-5.468,9.114l16.031,64.125c0.791,3.162,3.529,5.455,6.781,5.674    c3.241,0.215,6.276-1.679,7.487-4.706l10.404-26.012l16.253,27.087c1.736,2.894,5.298,4.291,8.542,3.35    c2.851-0.828,4.991-3.339,5.359-6.283l8.016-64.125C440.317,172.657,437.395,168.901,433.277,168.386z' />
                    </svg>
                    <span>Follow Us</span>
                </div>
                <div className='links'>
                    <a href='https://www.facebook.com/ProxyScrape-2293011407635184/' title='Facebook' onClick={openLink}>
                        <svg viewBox='0 0 512 512'>
                            <path d='m75 512h167v-182h-60v-60h60v-75c0-41.355469 33.644531-75 75-75h75v60h-60c-16.542969 0-30 13.457031-30 30v60h87.292969l-10 60h-77.292969v182h135c41.355469 0 75-33.644531 75-75v-362c0-41.355469-33.644531-75-75-75h-362c-41.355469 0-75 33.644531-75 75v362c0 41.355469 33.644531 75 75 75zm-45-437c0-24.8125 20.1875-45 45-45h362c24.8125 0 45 20.1875 45 45v362c0 24.8125-20.1875 45-45 45h-105v-122h72.707031l20-120h-92.707031v-30h90v-120h-105c-57.898438 0-105 47.101562-105 105v45h-60v120h60v122h-137c-24.8125 0-45-20.1875-45-45zm0 0' />
                        </svg>
                        <span>Facebook</span>
                    </a>
                    <a href='https://twitter.com/proxyscrape_off' title='Twitter' onClick={openLink}>
                        <svg viewBox='0 -47 512.00004 512'>
                            <path d='m512 55.964844c-32.207031 1.484375-31.503906 1.363281-35.144531 1.667968l19.074219-54.472656s-59.539063 21.902344-74.632813 25.820313c-39.640625-35.628907-98.5625-37.203125-140.6875-11.3125-34.496094 21.207031-53.011719 57.625-46.835937 100.191406-67.136719-9.316406-123.703126-41.140625-168.363282-94.789063l-14.125-16.964843-10.554687 19.382812c-13.339844 24.492188-17.769531 52.496094-12.476563 78.851563 2.171875 10.8125 5.863282 21.125 10.976563 30.78125l-12.117188-4.695313-1.4375 20.246094c-1.457031 20.566406 5.390625 44.574219 18.320313 64.214844 3.640625 5.53125 8.328125 11.605469 14.269531 17.597656l-6.261719-.960937 7.640625 23.199218c10.042969 30.480469 30.902344 54.0625 57.972657 67.171875-27.035157 11.472657-48.875 18.792969-84.773438 30.601563l-32.84375 10.796875 30.335938 16.585937c11.566406 6.324219 52.4375 27.445313 92.820312 33.78125 89.765625 14.078125 190.832031 2.613282 258.871094-58.664062 57.308594-51.613282 76.113281-125.03125 72.207031-201.433594-.589844-11.566406 2.578125-22.605469 8.921875-31.078125 12.707031-16.964844 48.765625-66.40625 48.84375-66.519531zm-72.832031 48.550781c-10.535157 14.066406-15.8125 32.03125-14.867188 50.578125 3.941407 77.066406-17.027343 136.832031-62.328125 177.628906-52.917968 47.660156-138.273437 66.367188-234.171875 51.324219-17.367187-2.722656-35.316406-8.820313-50.171875-14.910156 30.097656-10.355469 53.339844-19.585938 90.875-37.351563l52.398438-24.800781-57.851563-3.703125c-27.710937-1.773438-50.785156-15.203125-64.96875-37.007812 7.53125-.4375 14.792969-1.65625 22.023438-3.671876l55.175781-15.367187-55.636719-13.625c-27.035156-6.621094-42.445312-22.796875-50.613281-35.203125-5.363281-8.152344-8.867188-16.503906-10.96875-24.203125 5.578125 1.496094 12.082031 2.5625 22.570312 3.601563l51.496094 5.09375-40.800781-31.828126c-29.398437-22.929687-41.179687-57.378906-32.542969-90.496093 91.75 95.164062 199.476563 88.011719 210.320313 90.527343-2.386719-23.183593-2.449219-23.238281-3.074219-25.445312-13.886719-49.089844 16.546875-74.015625 30.273438-82.453125 28.671874-17.621094 74.183593-20.277344 105.707031 8.753906 6.808593 6.265625 16.015625 8.730469 24.632812 6.589844 7.734375-1.921875 14.082031-3.957031 20.296875-6.171875l-12.9375 36.945312 16.515625.011719c-3.117187 4.179688-6.855469 9.183594-11.351562 15.183594zm0 0' />
                        </svg>
                        <span>Twitter</span>
                    </a>
                    <a href='https://www.linkedin.com/company/proxyscrape/' title='Linkedin' onClick={openLink}>
                        <svg viewBox="0 0 512 512">
                          <path d="M186.4 142.4c0 19-15.3 34.5-34.2 34.5 -18.9 0-34.2-15.4-34.2-34.5 0-19 15.3-34.5 34.2-34.5C171.1 107.9 186.4 123.4 186.4 142.4zM181.4 201.3h-57.8V388.1h57.8V201.3zM273.8 201.3h-55.4V388.1h55.4c0 0 0-69.3 0-98 0-26.3 12.1-41.9 35.2-41.9 21.3 0 31.5 15 31.5 41.9 0 26.9 0 98 0 98h57.5c0 0 0-68.2 0-118.3 0-50-28.3-74.2-68-74.2 -39.6 0-56.3 30.9-56.3 30.9v-25.2H273.8z"/>
                        </svg>
                        <span>Linkedin</span>
                    </a>

                </div>
                <div className='section'>
                    <svg viewBox='0 0 512.001 512.001'>
                        <path d='M404.99,344.077c-26.743,0-50.588,12.583-65.974,32.124l-154.093-88.964c3.888-9.662,6.049-20.198,6.049-31.236    c0-11.037-2.162-21.573-6.049-31.236l154.093-88.964c15.387,19.54,39.231,32.124,65.974,32.124    c46.297,0,83.962-37.666,83.962-83.962C488.952,37.666,451.288,0,404.99,0s-83.962,37.665-83.962,83.961    c0,11.038,2.163,21.576,6.052,31.24l-154.091,88.964c-15.387-19.542-39.233-32.127-65.978-32.127    c-46.297,0-83.962,37.666-83.962,83.962c0,46.296,37.665,83.962,83.962,83.962c26.745,0,50.591-12.585,65.978-32.127L327.08,396.8    c-3.889,9.664-6.052,20.201-6.052,31.24c0,46.297,37.665,83.961,83.962,83.961s83.962-37.665,83.962-83.961    C488.952,381.744,451.288,344.077,404.99,344.077z M404.99,23.808c33.169,0,60.155,26.985,60.155,60.153    c0,33.169-26.985,60.155-60.155,60.155c-33.169,0-60.155-26.986-60.155-60.155C344.836,50.792,371.822,23.808,404.99,23.808z     M107.011,316.155c-33.169,0-60.155-26.986-60.155-60.155c0-33.169,26.985-60.155,60.155-60.155    c33.169,0,60.155,26.986,60.155,60.155C167.166,289.169,140.18,316.155,107.011,316.155z M404.99,488.192    c-33.169,0-60.155-26.985-60.155-60.153c0-33.169,26.985-60.155,60.155-60.155c33.169,0,60.155,26.986,60.155,60.155    C465.145,461.208,438.159,488.192,404.99,488.192z' />
                        <path d='M107.011,220.606c-19.516,0-35.394,15.877-35.394,35.394c0,6.573,5.329,11.904,11.904,11.904s11.904-5.331,11.904-11.904    c0-6.389,5.197-11.586,11.586-11.586c6.574,0,11.904-5.331,11.904-11.904C118.915,225.936,113.585,220.606,107.011,220.606z' />
                    </svg>
                    <span>Share the Checker</span>
                </div>
                <div className='links'>
                    <a href='https://facebook.com/sharer/sharer.php?u=https://proxyscrape.com/proxy-checker' title='on Facebook' onClick={openLink}>
                        <svg viewBox='0 0 512 512'>
                            <path d='m75 512h167v-182h-60v-60h60v-75c0-41.355469 33.644531-75 75-75h75v60h-60c-16.542969 0-30 13.457031-30 30v60h87.292969l-10 60h-77.292969v182h135c41.355469 0 75-33.644531 75-75v-362c0-41.355469-33.644531-75-75-75h-362c-41.355469 0-75 33.644531-75 75v362c0 41.355469 33.644531 75 75 75zm-45-437c0-24.8125 20.1875-45 45-45h362c24.8125 0 45 20.1875 45 45v362c0 24.8125-20.1875 45-45 45h-105v-122h72.707031l20-120h-92.707031v-30h90v-120h-105c-57.898438 0-105 47.101562-105 105v45h-60v120h60v122h-137c-24.8125 0-45-20.1875-45-45zm0 0' />
                        </svg>
                        <span>Facebook</span>
                    </a>
                    <a href='https://twitter.com/intent/tweet/?url=https://proxyscrape.com/proxy-checker' title='on Twitter' onClick={openLink}>
                        <svg viewBox='0 -47 512.00004 512'>
                            <path d='m512 55.964844c-32.207031 1.484375-31.503906 1.363281-35.144531 1.667968l19.074219-54.472656s-59.539063 21.902344-74.632813 25.820313c-39.640625-35.628907-98.5625-37.203125-140.6875-11.3125-34.496094 21.207031-53.011719 57.625-46.835937 100.191406-67.136719-9.316406-123.703126-41.140625-168.363282-94.789063l-14.125-16.964843-10.554687 19.382812c-13.339844 24.492188-17.769531 52.496094-12.476563 78.851563 2.171875 10.8125 5.863282 21.125 10.976563 30.78125l-12.117188-4.695313-1.4375 20.246094c-1.457031 20.566406 5.390625 44.574219 18.320313 64.214844 3.640625 5.53125 8.328125 11.605469 14.269531 17.597656l-6.261719-.960937 7.640625 23.199218c10.042969 30.480469 30.902344 54.0625 57.972657 67.171875-27.035157 11.472657-48.875 18.792969-84.773438 30.601563l-32.84375 10.796875 30.335938 16.585937c11.566406 6.324219 52.4375 27.445313 92.820312 33.78125 89.765625 14.078125 190.832031 2.613282 258.871094-58.664062 57.308594-51.613282 76.113281-125.03125 72.207031-201.433594-.589844-11.566406 2.578125-22.605469 8.921875-31.078125 12.707031-16.964844 48.765625-66.40625 48.84375-66.519531zm-72.832031 48.550781c-10.535157 14.066406-15.8125 32.03125-14.867188 50.578125 3.941407 77.066406-17.027343 136.832031-62.328125 177.628906-52.917968 47.660156-138.273437 66.367188-234.171875 51.324219-17.367187-2.722656-35.316406-8.820313-50.171875-14.910156 30.097656-10.355469 53.339844-19.585938 90.875-37.351563l52.398438-24.800781-57.851563-3.703125c-27.710937-1.773438-50.785156-15.203125-64.96875-37.007812 7.53125-.4375 14.792969-1.65625 22.023438-3.671876l55.175781-15.367187-55.636719-13.625c-27.035156-6.621094-42.445312-22.796875-50.613281-35.203125-5.363281-8.152344-8.867188-16.503906-10.96875-24.203125 5.578125 1.496094 12.082031 2.5625 22.570312 3.601563l51.496094 5.09375-40.800781-31.828126c-29.398437-22.929687-41.179687-57.378906-32.542969-90.496093 91.75 95.164062 199.476563 88.011719 210.320313 90.527343-2.386719-23.183593-2.449219-23.238281-3.074219-25.445312-13.886719-49.089844 16.546875-74.015625 30.273438-82.453125 28.671874-17.621094 74.183593-20.277344 105.707031 8.753906 6.808593 6.265625 16.015625 8.730469 24.632812 6.589844 7.734375-1.921875 14.082031-3.957031 20.296875-6.171875l-12.9375 36.945312 16.515625.011719c-3.117187 4.179688-6.855469 9.183594-11.351562 15.183594zm0 0' />
                        </svg>
                        <span>Twitter</span>
                    </a>
                    <a href='https://reddit.com/submit/?url=https://proxyscrape.com/proxy-checker&title=ProxyScrape Proxy Checker' title='on Reddit' onClick={openLink}>
                        <svg viewBox='0 -16 512 512'>
                            <path d='m158.578125 399.609375c27.753906 13.148437 62.351563 20.390625 97.421875 20.390625s69.667969-7.242188 97.421875-20.390625l-12.84375-27.113281c-23.824219 11.289062-53.859375 17.503906-84.578125 17.503906s-60.753906-6.214844-84.578125-17.503906zm0 0' />
                            <path d='m31.960938 293.085938c-1.292969 7.203124-1.960938 14.515624-1.960938 21.914062 0 45.019531 24.265625 87.03125 68.328125 118.300781 42.4375 30.113281 98.433594 46.699219 157.671875 46.699219s115.234375-16.585938 157.671875-46.699219c44.0625-31.269531 68.328125-73.28125 68.328125-118.300781 0-7.398438-.667969-14.710938-1.960938-21.914062 19.359376-10.164063 31.960938-30.320313 31.960938-53.085938 0-33.085938-26.914062-60-60-60-15.082031 0-29.292969 5.589844-40.175781 15.421875-39.355469-27.316406-90.023438-43.175781-144.023438-45.195313l28.664063-111.175781 65.578125 22.691407c.929687 32.28125 27.457031 58.257812 59.957031 58.257812 33.085938 0 60-26.914062 60-60s-26.914062-60-60-60c-23.109375 0-43.191406 13.140625-53.214844 32.332031l-93.25-32.2656248-38.8125 150.5351558c-51.1875 3.144532-99.015625 18.765626-136.546875 44.820313-10.882812-9.832031-25.09375-15.421875-40.175781-15.421875-33.085938 0-60 26.914062-60 60 0 22.765625 12.601562 42.921875 31.960938 53.085938zm390.039062-263.085938c16.542969 0 30 13.457031 30 30s-13.457031 30-30 30-30-13.457031-30-30 13.457031-30 30-30zm60 210c0 9.367188-4.273438 17.835938-11.167969 23.378906-7.816406-17.46875-19.625-33.855468-35.105469-48.582031 4.773438-3.085937 10.386719-4.796875 16.273438-4.796875 16.542969 0 30 13.457031 30 30zm-226-60c53.070312 0 102.902344 14.621094 140.3125 41.167969 35.910156 25.480469 55.6875 58.804687 55.6875 93.832031s-19.777344 68.351562-55.6875 93.832031c-37.410156 26.546875-87.242188 41.167969-140.3125 41.167969s-102.902344-14.621094-140.3125-41.167969c-35.910156-25.480469-55.6875-58.804687-55.6875-93.832031s19.777344-68.351562 55.6875-93.832031c37.410156-26.546875 87.242188-41.167969 140.3125-41.167969zm-196 30c5.886719 0 11.5 1.710938 16.273438 4.796875-15.480469 14.726563-27.289063 31.113281-35.105469 48.582031-6.894531-5.542968-11.167969-14.011718-11.167969-23.378906 0-16.542969 13.457031-30 30-30zm0 0' />
                            <path d='m165 330c24.8125 0 45-20.1875 45-45s-20.1875-45-45-45-45 20.1875-45 45 20.1875 45 45 45zm0-60c8.269531 0 15 6.730469 15 15s-6.730469 15-15 15-15-6.730469-15-15 6.730469-15 15-15zm0 0' />
                            <path d='m347 330c24.8125 0 45-20.1875 45-45s-20.1875-45-45-45-45 20.1875-45 45 20.1875 45 45 45zm0-60c8.269531 0 15 6.730469 15 15s-6.730469 15-15 15-15-6.730469-15-15 6.730469-15 15-15zm0 0' />
                        </svg>
                        <span>Reddit</span>
                    </a>
                    <a href='https://telegram.me/share/url?text=ProxyScrape Proxy Checker&url=https://proxyscrape.com/proxy-checker' title='on Telegram' onClick={openLink}>
                        <svg viewBox='1 -35 511.99993 511'>
                            <path d='m121.453125 253.171875 63.554687 158.886719 82.75-82.753906 141.535157 112.503906 102.707031-441.308594-512 205.480469zm-39.933594-47.640625 244.046875-97.945312-194.074218 117.363281zm287.535157-89.25-161.980469 148.1875-19.484375 73.425781-36.035156-90.085937zm-149.851563 219.230469 9.816406-36.996094 15.144531 12.035156zm171.65625 53.394531-147.386719-117.152344 221.902344-203.007812zm0 0' />
                        </svg>
                        <span>Telegram</span>
                    </a>
                </div>
                <div className='section rel'>
                    <svg viewBox='0 0 522.468 522.469'>
                        <path d='M325.762,70.513l-17.706-4.854c-2.279-0.76-4.524-0.521-6.707,0.715c-2.19,1.237-3.669,3.094-4.429,5.568L190.426,440.53    c-0.76,2.475-0.522,4.809,0.715,6.995c1.237,2.19,3.09,3.665,5.568,4.425l17.701,4.856c2.284,0.766,4.521,0.526,6.71-0.712    c2.19-1.243,3.666-3.094,4.425-5.564L332.042,81.936c0.759-2.474,0.523-4.808-0.716-6.999    C330.088,72.747,328.237,71.272,325.762,70.513z' />
                        <path d='M166.167,142.465c0-2.474-0.953-4.665-2.856-6.567l-14.277-14.276c-1.903-1.903-4.093-2.857-6.567-2.857    s-4.665,0.955-6.567,2.857L2.856,254.666C0.95,256.569,0,258.759,0,261.233c0,2.474,0.953,4.664,2.856,6.566l133.043,133.044    c1.902,1.906,4.089,2.854,6.567,2.854s4.665-0.951,6.567-2.854l14.277-14.268c1.903-1.902,2.856-4.093,2.856-6.57    c0-2.471-0.953-4.661-2.856-6.563L51.107,261.233l112.204-112.201C165.217,147.13,166.167,144.939,166.167,142.465z' />
                        <path d='M519.614,254.663L386.567,121.619c-1.902-1.902-4.093-2.857-6.563-2.857c-2.478,0-4.661,0.955-6.57,2.857l-14.271,14.275    c-1.902,1.903-2.851,4.09-2.851,6.567s0.948,4.665,2.851,6.567l112.206,112.204L359.163,373.442    c-1.902,1.902-2.851,4.093-2.851,6.563c0,2.478,0.948,4.668,2.851,6.57l14.271,14.268c1.909,1.906,4.093,2.854,6.57,2.854    c2.471,0,4.661-0.951,6.563-2.854L519.614,267.8c1.903-1.902,2.854-4.096,2.854-6.57    C522.468,258.755,521.517,256.565,519.614,254.663z' />
                    </svg>
                    <span>Releases</span>
                </div>
                <div className='releases'>
                    {releases.map(release => (
                        <div className='release' key={release.tag_name}>
                            <span className='version'>{release.tag_name}</span>
                            <div className='published'>
                                <svg viewBox='0 0 485.213 485.212'>
                                    <path d='M60.652,75.816V15.163C60.652,6.781,67.433,0,75.817,0c8.38,0,15.161,6.781,15.161,15.163v60.653   c0,8.38-6.781,15.161-15.161,15.161C67.433,90.978,60.652,84.196,60.652,75.816z M318.424,90.978   c8.378,0,15.163-6.781,15.163-15.161V15.163C333.587,6.781,326.802,0,318.424,0c-8.382,0-15.168,6.781-15.168,15.163v60.653   C303.256,84.196,310.042,90.978,318.424,90.978z M485.212,363.906c0,66.996-54.312,121.307-121.303,121.307   c-66.986,0-121.302-54.311-121.302-121.307c0-66.986,54.315-121.3,121.302-121.3C430.9,242.606,485.212,296.919,485.212,363.906z    M454.89,363.906c0-50.161-40.81-90.976-90.98-90.976c-50.166,0-90.976,40.814-90.976,90.976c0,50.171,40.81,90.98,90.976,90.98   C414.08,454.886,454.89,414.077,454.89,363.906z M121.305,181.955H60.652v60.651h60.653V181.955z M60.652,333.584h60.653V272.93   H60.652V333.584z M151.629,242.606h60.654v-60.651h-60.654V242.606z M151.629,333.584h60.654V272.93h-60.654V333.584z    M30.328,360.891V151.628h333.582v60.653h30.327V94c0-18.421-14.692-33.349-32.843-33.349h-12.647v15.166   c0,16.701-13.596,30.325-30.322,30.325c-16.731,0-30.326-13.624-30.326-30.325V60.651H106.14v15.166   c0,16.701-13.593,30.325-30.322,30.325c-16.733,0-30.327-13.624-30.327-30.325V60.651H32.859C14.707,60.651,0.001,75.579,0.001,94   v266.892c0,18.36,14.706,33.346,32.858,33.346h179.424v-30.331H32.859C31.485,363.906,30.328,362.487,30.328,360.891z    M303.256,242.606v-60.651h-60.648v60.651H303.256z M409.399,363.906h-45.49v-45.49c0-8.377-6.781-15.158-15.163-15.158   s-15.159,6.781-15.159,15.158v60.658c0,8.378,6.777,15.163,15.159,15.163h60.653c8.382,0,15.163-6.785,15.163-15.163   C424.562,370.692,417.781,363.906,409.399,363.906z' />
                                </svg>
                                <span className='date'>{new Date(release.published_at).toLocaleString()}</span>
                            </div>
                            <div className='notes'>
                                <ReactMarkdown source={release.body} />
                            </div>
                        </div>
                    ))}
                </div>
            </div>
        </div>
    );
});

export default Info;
